Date

Struct Date 

pub struct Date(/* private fields */);
Represents a date.

Implementations

Source

impl Date

pub const UNIX_EPOCH: Self

pub const fn year(self) -> u32

The year for this date.

pub const fn month_int(self) -> u8

The month for this date as an int, between 1 and 12.

pub fn month(self) -> Month

The month for this date.

pub const fn day(self) -> u8

The day of the month for this date, as an int between 1 and 31.

pub const fn create(year: u32, month: Month, day: u8) -> Result<Self, DateError>

Create a date based on a year, a month, and a day.

pub fn to_string_iso8601_extended(self) -> String

String representation for the current date, e.g. “2021-01-16”.

pub fn to_string_iso8601_basic(self) -> String

String representation for the current date, e.g. “20210116”.

pub fn to_string_american(self) -> String

String representation for the current date, e.g. “01/16/2021”.

pub fn add_days(self, n: i32) -> Self

Add a number of days to this date.

pub fn add_months(self, m: i32) -> Self

Add some number of months to a date. This returns the date with the last day of the month in the case where the actual date would be invalid, e.g. adding a month to Jan 31 results in Feb 28 or Feb 29 depending on whether it’s a leap year or not.

pub fn add_years(self, y: i32) -> Self

Add some number of years to a date. If the returned day would not exist (e.g. Feb 28), the last day of the target month is returned.

pub fn day_of_week(self) -> DayOfWeek

The day of the week for this date.

pub fn of_days_since_epoch(d: i32) -> Self

The number of days since epoch (1970-01-01).

pub fn today(tz: Tz) -> Self

The current date in the given timezone, this calls Time::now.

pub fn is_weekday(self) -> bool

pub fn is_weekend(self) -> bool

pub fn round_forward_to_business_day<F>(self, is_business_day: F) -> Self
where F: Fn(Self) -> bool,

Rounds the date to the next value that satisfies is_business_day if it is not already a business day.

pub fn round_backward_to_business_day<F>(self, is_business_day: F) -> Self
where F: Fn(Self) -> bool,

Rounds the date to the previous value that satisfies is_business_day if it is not already a business day.

pub fn add_business_days_rounding_backward<F>( self, days: i64, is_business_day: F, ) -> Self
where F: Fn(Self) -> bool,

First rounds the given date backward to the previous business day as defined by F if it does not already satisfy it. Then advances by the given number of business days which may be negative.

pub fn add_business_days_rounding_forward<F>( self, days: i64, is_business_day: F, ) -> Self
where F: Fn(Self) -> bool,

First rounds the given date forward to the next business day as defined by F if it does not already satisfy it. Then advances by the given number of business days which may be negative.

Source

impl Date

pub fn dates_between(lo: Self, up: Self) -> DatesBetween

Lists all the dates between two dates (inclusive).

pub fn dates_until(self, up: Self) -> DatesBetween

Lists all the dates from the self date until up (inclusive).

Source

impl Date

pub fn weekdays_between(lo: Self, up: Self) -> WeekdaysBetween

Lists all the weekdays between two dates (inclusive).

pub fn weekdays_until(self, up: Self) -> WeekdaysBetween

Lists all the weekdays from the self date until up (inclusive).

Source

impl Date

pub fn business_days_between<F>( lo: Self, up: Self, is_business_day: F, ) -> BusinessDaysBetween<F>
where F: Fn(Self) -> bool,

Lists all the business days between two dates (inclusive).

pub fn business_days_until<F>( self, up: Self, is_business_day: F, ) -> BusinessDaysBetween<F>
where F: Fn(Self) -> bool,

Lists all the business days from the self date until up (inclusive).